%%% MAKE FIG 3 %%%

%% DEFINE PARAMETERS %%

%%%TIME%%%
time = [0 0.5]; %time to integrate over [s]
t_fire = 0.1; %time at which airgun stops firing [s]

%%%CONSTANTS%%%
Rgas = 287.06; %specific gas constant for dry air [J/kgK]
cv = 718; %heat capacity of air at constant volume [J/kgK]
cp = 1010; %heat capacity of air at constant pressure [J/kgK]
gamma = 1.4; %ratio of heat capacities for dry air
B = 303975000; %constant from Tait's equation of state
n = 7; %constant from Tait's equation of state
M = 10; %surface magnification due to turbulence
kappa = 0.04; %heat conduction coefficient

%%%AMBIENT PROPERTIES%%%
rho_infty = 1000; %density infinitely far from bubble [kg/m^3]
depth = 25; %depth of airgun [m]
p0 = 1e5; %atmospheric pressure [Pa];
g = 9.8; %gravitational acceleration [m/s^2]
p_infty = p0 + rho_infty*g*depth; %pressure infinitely far from bubble [Pa]
T_infty = 279; %temperature infinitely far from bubble [K]
c_infty = sqrt(n*((p_infty + B)/rho_infty)); %speed of sound in liquid infinitely far from bubble
r = 10; %distance from bubble to compute pressure field at [m]

%%%AIRGUN%%%
init_p_airgun_psi = 2000; %pressure in airgun [psi]
init_p_airgun = init_p_airgun_psi*6894.8; %pressure in airgun [Pa]
V_airgun = 400; %volume of airgun [in^3]
V_airgun = V_airgun*1.63871e-5; %volume of airgun [m^3]
init_T_airgun = T_infty; %temperature of gas inside airgun [K]
init_m_airgun = (init_p_airgun*V_airgun)/(Rgas*init_T_airgun); %mass of gas inside airgun [kg]
A1 = 2; A1 = A1 * 2.54e-2; %dimension of airgun nozzle [m];
A2 = 2; A2 = A2 * 2.54e-2; %dimension of airgun nozzle [m];
A = A1*A2;


%% SOLVER %%

%initialize bubble and airgun with variables from asymptotic solution
init_V_bubble = V_airgun;
init_radius = ((3*init_V_bubble)/(4*pi))^(1/3);
init_velocity = 0;
init_T_bubble = T_infty;
init_p_bubble = p_infty;
init_m_bubble = (init_p_bubble*init_V_bubble)/(Rgas*init_T_bubble);

%define initial conditions
init_cond = [init_radius, init_velocity, init_m_bubble, init_T_bubble,...
    init_p_airgun, init_m_airgun];

%define parameters required by solve
params = [Rgas gamma p_infty rho_infty T_infty V_airgun A...
    cv cp M kappa c_infty t_fire init_m_airgun];

options = odeset('RelTol',1e-6);
[t, Y] = ode45(@modified_herring_eqn, time, init_cond, options, params);

R = real(Y(:,1));  U = real(Y(:,2)); m_bubble = real(Y(:,3)); 
T_bubble = real(Y(:,4)); p_airgun = real(Y(:,5)); m_airgun = real(Y(:,6)); 
p_bubble = m_bubble.*Rgas.*T_bubble./(4/3*pi*R.^3);
E_bubble = m_bubble.*cv.*T_bubble;
T_airgun = p_airgun*V_airgun./(m_airgun*Rgas);


FigHandle = figure;
set(FigHandle, 'Position', [100, 100, 1049, 895]);

subplot(2,6,1:3); 
plot(t, R,'LineWidth',2); xlim([0 0.5]); title('radius (m)'); xlabel('time (s)');

subplot(2,6,4:6);
plot(t, U,'LineWidth',2); xlim([0 0.5]); title('velocity (m/s)'); xlabel('time (s)');

subplot(2,6,7:8);
plot(t, m_bubble,'LineWidth',2); hold on; xlim([0 0.5]);
plot(t, m_airgun,'LineWidth',2); title('mass (kg)');
legend('bubble','airgun'); xlabel('time (s)');

subplot(2,6,9:10);
plot(t, T_bubble,'LineWidth',2); hold on; xlim([0 0.5]);
plot(t, T_airgun,'LineWidth',2); title('temperature (K)');
legend('bubble','airgun'); xlabel('time (s)');

subplot(2,6,11:12);
semilogy(t, p_bubble,'LineWidth',2); hold on; xlim([0 0.5]);
semilogy(t, p_airgun,'LineWidth',2); title('pressure (Pa)');
legend('bubble','airgun'); xlabel('time (s)');

print('modelOutputs','-dpdf');
