%%% MAKE FIG 4 %%%

%% INITIALIZATION %%

%%%TIME%%%
time = [0 0.5]; %time to integrate over [s]
t_fire = 0.1; %time at which airgun stops firing [s]

%%%CONSTANTS%%%
Rgas = 287.06; %specific gas constant for dry air [J/kgK]
cv = 718; %heat capacity of air at constant volume [J/kgK]
cp = 1010; %heat capacity of air at constant pressure [J/kgK]
gamma = 1.4; %ratio of heat capacities for dry air
B = 303975000; %constant from Tait's equation of state
n = 7; %constant from Tait's equation of state
M = 10; %surface magnification due to turbulence
kappa = 0.04; %heat conduction coefficient

%%%AMBIENT PROPERTIES%%%
rho_infty = 1000; %density infinitely far from bubble [kg/m^3]
depth = 25; %depth of airgun [m]
p0 = 1e5; %atmospheric pressure [Pa];
g = 9.8; %gravitational acceleration [m/s^2]
p_infty = p0 + rho_infty*g*depth; %pressure infinitely far from bubble [Pa]
T_infty = 279; %temperature infinitely far from bubble [K]
c_infty = sqrt(n*((p_infty + B)/rho_infty)); %speed of sound in liquid infinitely far from bubble
r = 10; %distance from bubble to compute pressure field at [m]

%%%AIRGUN%%%
init_p_airgun_psi = 2040; %pressure in airgun [psi]
init_p_airgun = init_p_airgun_psi*6894.8; %pressure in airgun [Pa]
V_airgun = 400; %volume of airgun [in^3]
V_airgun = V_airgun*1.63871e-5; %volume of airgun [m^3]
init_T_airgun = T_infty; %temperature of gas inside airgun [K]
init_m_airgun = (init_p_airgun*V_airgun)/(Rgas*init_T_airgun); %mass of gas inside airgun [kg]
A1 = 2; A1 = A1 * 2.54e-2; %dimension of airgun nozzle [m];
A2 = 4; A2 = A2 * 2.54e-2; %dimension of airgun nozzle [m];
A = A1*A2;

params = [Rgas gamma p_infty rho_infty T_infty V_airgun A...
    cv cp M kappa c_infty t_fire init_m_airgun];

%%%BUBBLE%%%
init_V_bubble = V_airgun;
init_radius = ((3*init_V_bubble)/(4*pi))^(1/3);
init_velocity = 0;
init_T_bubble = T_infty;
init_p_bubble = p_infty;
init_m_bubble = (init_p_bubble*init_V_bubble)/(Rgas*init_T_bubble);
init_cond = [init_radius, init_velocity, init_m_bubble, init_T_bubble,...
    init_p_airgun, init_m_airgun];

%%%SOLVER OPTIONS%%%
options = odeset('RelTol',1e-6);

%% GILMORE %%

[t, Y] = ode45(@gilmore_eqn, time, init_cond, options, params);
Rmax = max(Y(:,1));
Rnorm = Y(:,1)./Rmax;

FigHandle = figure;
set(FigHandle, 'Position', [100, 100, 1000, 400]);
subplot(1,2,1);
plot(t, Rnorm,'LineWidth',2); hold on;
set(gca,'FontSize',16);
ylabel('normalized R'); xlabel('time (s)');
ylim([0.1 1.1])
xlim([0 0.5])
B = 3.04913e8; n = 7.15;
pb = Y(:,3).*Rgas.*Y(:,4)./(4/3*pi.*Y(:,1).^3);
[tPres, pPres] = pressure_gilmore(t, Y(:,1), Y(:,2), pb, rho_infty, c_infty, p_infty, r, B, n);

for i = 1:length(pPres);
    if isnan(pPres(i));
        pPres(i) = 0;
    end
end

pPresmax = max(pPres);
pPresnorm = pPres./pPresmax;

subplot(1,2,2);
plot(tPres, pPresnorm,'LineWidth',2); hold on;
set(gca,'FontSize',16);
xlim([0 max(time)]); xlabel('time (s)');
ylabel('normalized \Delta p');


%% MODIFIED HERRING AND KELLER/KOLODNER %%

[t, Y] = ode45(@modified_herring_eqn, time, init_cond, options, params);
Rnorm = Y(:,1)./Rmax;
subplot(1,2,1);
plot(t, Rnorm,'LineStyle','--','LineWidth',2);
legend('Gilmore','Modified Herring')

[tPres, pPres] = pressure_keller(t, Y(:,1), Y(:,2), rho_infty, c_infty, r);
pPresnorm = pPres./pPresmax;

subplot(1,2,2);
plot(tPres, pPresnorm,'LineStyle','--','LineWidth',2);
legend('Gilmore','Keller and Kolodner')


print('modelCompare','-dpdf');